const Cache = require('../../utils/cache.js');

Page({
  data: {
    searchValue: "", // 搜索框的内容
    hotKeywords: ["组件库", "小程序", "李白", "李清照"], // 热门搜索关键字
    searchHistory: [], // 从缓存中获取搜索历史，初始化为空数组
  },

  onShow() {
    this.getSearchHistory(); // 页面显示时读取搜索历史
    this.setNavigationBarColor();
  },
  setNavigationBarColor() {
    const themeColor = Cache.get('themeColor') || '#406Eff';
    this.hexToRgb(themeColor);
    const textColor = Cache.get('textColor') || '#ffffff';
    const userInfo = Cache.get('userInfo')||'';
    this.setData({
      themeColor,
      textColor,
      userInfo
    })
    wx.setNavigationBarColor({
      frontColor: textColor,
      backgroundColor: themeColor,
      animation: {
        duration: 400,
        timingFunc: 'easeIn'
      }
    })
  },
  hexToRgb(hex) {
    console.log(hex)
    hex = hex.replace(/^#/, '');
    var bigint = parseInt(hex, 16);
    var r = (bigint >> 16) & 255;
    var g = (bigint >> 8) & 255;
    var b = bigint & 255;
    this.setData({
      boxshadow: `RGB(${r}, ${g}, ${b},0.2)`
    });
  },
  getSearchHistory: function () {
    const cachedHistory = Cache.get('searchHistory');
    // 如果缓存存在且格式正确，赋值给 searchHistory
    if (cachedHistory && Array.isArray(cachedHistory)) {
      this.setData({
        searchHistory: cachedHistory,
      });
    } else {
      // 如果缓存为空或者格式不正确，初始化为空数组
      this.setData({
        searchHistory: [],
      });
    }
  },

  // 输入搜索内容
  onInput(e) {
    this.setData({
      searchValue: e.detail.value,
    });
  },

  // 点击取消按钮
  onCancel() {
    this.setData({
      searchValue: "",
    });
  },

  // 选择热门搜索标签
  onSelectTag(e) {
    const keyword = e.currentTarget.dataset.item;
    this.addToHistory(keyword); // 将选中的热门搜索词添加到历史记录
    wx.showToast({
      title: `搜索：${keyword}`,
      icon: "none",
    });
  },

  // 选择历史记录
  onSelectHistory(e) {
    const keyword = e.currentTarget.dataset.item;
    this.setData({
      searchValue: keyword,
    });
    wx.showToast({
      title: `搜索：${keyword}`,
      icon: "none",
    });
  },

  // 添加到搜索历史
  addToHistory(keyword) {
    let history = this.data.searchHistory || []; // 确保 history 总是数组
    if (history.includes(keyword)) {
      // 如果历史记录中已经有该关键词，移除并放到最前面
      history = history.filter((item) => item !== keyword);
    }
    history.unshift(keyword); // 将新的关键词添加到历史记录的最前面
    if (history.length > 12) {
      // 限制历史记录的数量最多为12条
      history.pop();
    }
    this.setData({
      searchHistory: history,
    });
    Cache.set('searchHistory', history); // 保存到缓存
  },

  // 清除搜索历史
  onClearHistory() {
    Cache.remove('searchHistory'); // 删除缓存中的搜索历史
    this.setData({
      searchHistory: [], // 清空历史记录
    });
    wx.showToast({
      title: "历史已清除",
      icon: "none",
    });
  },
});
