Page({
  data: {
    r: 64,
    shareMD: '',
    g: 110,
    b: 255,
    hexInput: '406eff',
    result: '#406eff'
  },

  onLoad(options) {},
  onShow() {
    this.setNavigationBarColor();
  },
  setNavigationBarColor() {
    const themeColor = Cache.get('themeColor') || '#406Eff';
    const textColor = Cache.get('textColor') || '#ffffff';
    wx.setNavigationBarColor({
      frontColor: textColor,
      backgroundColor: themeColor,
      animation: {
        duration: 400,
        timingFunc: 'easeIn'
      }
    })
  },
  getColor(color) {
    const rgbRegex = /^RGB\((\d{1,3}),\s*(\d{1,3}),\s*(\d{1,3})\)$/;
    const hexRegex = /^#?([0-9A-Fa-f]{6})$/;
    let r, g, b;
    let result = rgbRegex.exec(color);
    if (result) {
      r = parseInt(result[1]);
      g = parseInt(result[2]);
      b = parseInt(result[3]);
    } else {
      result = hexRegex.exec(color);
      if (result) {
        const hex = result[1];
        const bigint = parseInt(hex, 16);
        r = (bigint >> 16) & 255;
        g = (bigint >> 8) & 255;
        b = bigint & 255;
      } else {
        throw new Error("Invalid color input");
      }
    }
    this.setData({
      r,
      g,
      b
    })
    this.updateHexFromRgb();
  },

  onRChange(e) {
    this.setData({
      r: e.detail.value
    }, this.updateHexFromRgb);
  },

  onGChange(e) {
    this.setData({
      g: e.detail.value
    }, this.updateHexFromRgb);
  },

  onBChange(e) {
    this.setData({
      b: e.detail.value
    }, this.updateHexFromRgb);
  },

  onHexInput(e) {
    this.setData({
      hexInput: e.detail.value
    }, this.updateRgbFromHex);
  },

  rgbToHex(r, g, b) {
    return ((1 << 24) + (r << 16) + (g << 8) + b).toString(16).slice(1).toUpperCase();
  },

  hexToRgb(hex) {
    var bigint = parseInt(hex, 16);
    var r = (bigint >> 16) & 255;
    var g = (bigint >> 8) & 255;
    var b = bigint & 255;
    return {
      r,
      g,
      b
    };
  },

  updateHexFromRgb() {
    const {
      r,
      g,
      b
    } = this.data;
    const hex = this.rgbToHex(r, g, b);
    this.setData({
      hexInput: `${hex}`,
      result: `#${hex}`
    });
  },

  confirmSelection() {
    const selectedColor = this.data.result || `RGB(${this.data.r}, ${this.data.g}, ${this.data.b})`;
    if (selectedColor=="#FFFFFF"||selectedColor=="#000000") {
      wx.showToast({
        title: '不建议使用纯黑白哦！',
        icon: 'error'
      })
      return;
    }
    const pages = getCurrentPages();
    if (pages.length >= 2) {
      const prevPage = pages[pages.length - 2];
      if (prevPage && typeof prevPage.addNewColor === 'function') {
        prevPage.addNewColor(selectedColor);
        wx.showToast({
          title: '颜色已选择',
          icon: 'success'
        });
        wx.navigateBack();
      } else {
        wx.showToast({
          title: '上一页未定义方法',
          icon: 'none'
        });
      }
    } else {
      wx.showToast({
        title: '页面栈异常',
        icon: 'none'
      });
    }
  },
  copyRGB() {
    wx.setClipboardData({
      data: `RGB(${this.data.r}, ${this.data.g}, ${this.data.b})`,
      success: function (t) {
        wx.showToast({
          title: "复制成功",
          icon: "success",
          duration: 800
        }), setTimeout(function () {
          wx.hideToast({});
        }, 800);
      }
    });
  },
  copyHEX() {
    wx.setClipboardData({
      data: this.data.result,
      success: function (t) {
        wx.showToast({
          title: "复制成功",
          icon: "success",
          duration: 800
        }), setTimeout(function () {
          wx.hideToast({});
        }, 800);
      }
    });
  },

  updateRgbFromHex() {
    const hex = this.data.hexInput;
    if (/^[0-9A-Fa-f]{6}$/i.test(hex)) {
      const {
        r,
        g,
        b
      } = this.hexToRgb(hex);
      if (r !== this.data.r || g !== this.data.g || b !== this.data.b) {
        this.setData({
          r,
          g,
          b,
          result: `RGB(${r}, ${g}, ${b})`
        });
      }
    } else {
      this.setData({
        result: "请输入有效的16进制颜色"
      });
    }
  },

});